summaryrefslogtreecommitdiffstatshomepage
path: root/src/mame/video/kan_pand.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/mame/video/kan_pand.cpp')
-rw-r--r--src/mame/video/kan_pand.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mame/video/kan_pand.cpp b/src/mame/video/kan_pand.cpp
index 9c69ec2323b..30105a001ff 100644
--- a/src/mame/video/kan_pand.cpp
+++ b/src/mame/video/kan_pand.cpp
@@ -66,13 +66,13 @@ kaneko_pandora_device::kaneko_pandora_device(const machine_config &mconfig, cons
}
//-------------------------------------------------
// static_set_gfxdecode_tag: Set the tag of the
// gfx decoder
//-------------------------------------------------
-void kaneko_pandora_device::static_set_gfxdecode_tag(device_t &device, const char *tag)
+void kaneko_pandora_device::set_gfxdecode_tag(const char *tag)
{
- downcast<kaneko_pandora_device &>(device).m_gfxdecode.set_tag(tag);
+ m_gfxdecode.set_tag(tag);
}
//-------------------------------------------------
@@ -66,13 +66,13 @@ kaneko_pandora_device::kaneko_pandora_device(const machine_config &mconfig, cons
}
//-------------------------------------------------
-// static_set_gfxdecode_tag: Set the tag of the
+// set_gfxdecode_tag: Set the tag of the
// gfx decoder
//-------------------------------------------------